#!/usr/bin/env python
# Ubuntu CI Engine
# Copyright 2014 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import json
import os
import sys

import charmhelpers.contrib.charmsupport.nrpe
import charmhelpers.core.hookenv
import charmhelpers.payload.execd

from charmhelpers.core import host

hooks = charmhelpers.core.hookenv.Hooks()
log = charmhelpers.core.hookenv.log


###############################################################################
# Global variables
###############################################################################
proxy_confs = '/etc/apache2'
health_path = charmhelpers.core.hookenv.config()['health_path']
json_status_file = os.path.join(health_path, 'status_urls.json')


def _add_proxy(url_base, remote):
    with open(_conf_file(), 'w') as f:
        f.write(
            'RewriteRule ^/%s/(.*)$ %s$1 [P]\n' % (url_base, remote))
        f.write('ProxyPassReverse /%s %s\n' % (url_base, remote))
    host.service_restart('apache2')


@hooks.hook('proxy_logs-relation-broken')
def _remove_proxy():
    cf = _conf_file()
    if os.path.exists(cf):
        os.unlink(cf)
        host.service_restart('apache2')


@hooks.hook('json_status-relation-joined')
@hooks.hook('json_status-relation-changed')
def json_status_relation_joined():
    url = charmhelpers.core.hookenv.relation_get('status-url')
    unit = charmhelpers.core.hookenv.remote_unit()
    log('status URL is: %s' % url)

    rid = charmhelpers.core.hookenv.relation_id().replace(':', '_')

    data = {}
    if os.path.exists(json_status_file):
        data = json.load(open(json_status_file))
    data[rid] = {
        'url': '/' + rid + '/',
        'unit': unit,
    }

    with open(json_status_file, 'w') as f:
        json.dump(data, f)

    _add_proxy(rid, url)


@hooks.hook('json_status-relation-broken')
def json_status_relation_broken():
    if not os.path.exists(json_status_file):
        return

    data = json.load(open(json_status_file))
    rid = charmhelpers.core.hookenv.relation_id()
    if rid in data:
        del data[rid]
    with open(json_status_file, 'w') as f:
        json.dump(data, f)

    _remove_proxy()


@hooks.hook()
def install():
    if not os.path.exists(health_path):
        os.mkdir(health_path)
    if not os.path.exists(json_status_file):
        with open(json_status_file, 'w') as f:
            f.write('{}')


def _conf_file():
    # apache can't use a ":" in the Include directive so change it to a dash
    relation = 'juju-' + charmhelpers.core.hookenv.relation_id() + '.conf'
    return os.path.join(proxy_confs, relation.replace(':', '-'))


@hooks.hook('proxy_logs-relation-joined')
def proxy_logs_relation_joined():
    name, _ = charmhelpers.core.hookenv.remote_unit().split('/')
    addr = charmhelpers.core.hookenv.relation_get('private-address')

    _add_proxy('logs-' + name, 'http://' + addr + '/')


@hooks.hook('proxy_logs-relation-broken')
def proxy_logs_relation_broken():
    _remove_proxy()


if __name__ == "__main__":
    hooks.execute(sys.argv)