#!/usr/bin/env python
# Ubuntu Continuous Integration Engine
# Copyright 2014 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under
# the terms of the GNU General Public License version 3, as published by the
# Free Software Foundation.

# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranties of MERCHANTABILITY,
# SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.

import json
import mock

from ci_cli import utils
from ci_cli.tests import FakeRequestsReturn
from ci_utils.testing import TestCaseWithGnupg


config_contents = """auth_url: http://example.com
auth_user: user
auth_password: pass
auth_tenant_name: user_project
auth_region: region1
ci_url: http://example.com/ci
"""


class UtilsTestCase(TestCaseWithGnupg):
    def test_parse_id(self):
        location = 'http://www.example.com/api/v1/ticket/5/'
        id = utils.parse_id(location)
        self.assertEqual(id, '5')

    def test_parse_id_invalid_response(self):
        location = 'http://www.example.com/api/v1/ticket/'
        self.assertRaises(ValueError, utils.parse_id, location)

    def test_parse_id_not_int(self):
        location = 'http://www.example.com/api/v1/ticket/abc/123/'
        self.assertRaises(ValueError, utils.parse_id, location)

    @mock.patch('requests.get')
    def test_get_sourcepackage_uri(self, mock_requests):
        data = {"objects": [{"resource_uri": "/api/v1/sourcepackage/4/"}]}
        mock_requests.side_effect = [
            FakeRequestsReturn(200, json.dumps(data))
        ]
        uri = utils.get_sourcepackage_uri('foobar')
        mock_requests.assert_called_once()
        self.assertEquals(uri, '/api/v1/sourcepackage/4/')

    @mock.patch('requests.get')
    def test_get_sourcepackage_uri_not_found(self, mock_requests):
        data = {"objects": []}
        mock_requests.side_effect = [
            FakeRequestsReturn(200, json.dumps(data))
        ]
        uri = utils.get_sourcepackage_uri('foobar')
        mock_requests.assert_called_once()
        self.assertEquals(uri, '')

    def test_assert_valid_package_list_single(self):
        utils.assert_valid_package_list('foo')

    def test_assert_valid_package_list_three(self):
        utils.assert_valid_package_list('foo,bar,baz')

    def test_assert_valid_package_list_empty(self):
        utils.assert_valid_package_list(package_list_str=None)

    def test_assert_valid_package_list_with_space(self):
        with self.assertRaises(utils.InputError):
            utils.assert_valid_package_list('bar, baz')
