#!/bin/sh -e
# Ubuntu CI Engine
# Copyright 2014 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# REQUIRES: python-pip python-virtualenv python-setuptools python-dev make

export CI_DEPS_BRANCH="lp:~canonical-ci-engineering/uci-engine/deps"
# For OSX, see http://kaspermunck.github.io/2014/03/fixing-clang-error/
export ARCHFLAGS=-Wno-error=unused-command-line-argument-hard-error-in-future

pkgs='build-essential python-pip python-virtualenv python-setuptools python-dev make python-apt-dev'
if type dpkg 2>/dev/null && ! dpkg -s $pkgs 2>/dev/null >/dev/null ; then
    echo "Required packages are missing. Please ensure that the missing packages are installed."
    echo "Run: sudo apt-get install $pkgs"
    exit 1
fi


if [ -z $1 ] ; then
    # Create a temporary venv
    export venv=$(mktemp -d)
    if [ ! -z $TMPFS ] ; then
        echo "Using TMPFS for virtualenv"
        sudo mount -t tmpfs -o size=512M tmpfs $venv
        trap "echo cleaning up venv...; sudo umount $venv; sudo rm -rf $venv" EXIT
    else
        trap "echo cleaning up venv...; rm -rf $venv" EXIT
    fi
    virtualenv $venv
else
    # Use the provided one
    export venv=$1
fi

# Activate the venv
. $venv/bin/activate

# ci-utils comes first as it's common to several components and should be
# setup first
export SERVICES='
ci-utils
branch-source-builder
cli
gatekeeper
image-builder
lander
ppa-assigner
ticket_system
test_runner
publisher
'

FAILURES=0

for x in $SERVICES ; do
	echo "== Setting up $x ...."
	if ! ./$x/setup.py develop ; then
            echo "=== Setting up $x FAILED ==="
            FAILURES=$(( ${FAILURES} + 1 ))
        else
            echo "=== Setting up $x SUCCEEDED for $x ==="
        fi
done

# Install additional dependencies from our pip cache
# (respecting CI_DEPS_LOCAL).
if [ -z $CI_DEPS_LOCAL ] ; then
    PIP_CACHE=`pwd`/.deps
else
    # Ensure we use an absolute path as pip expects one
    PIP_CACHE=$(readlink -m $CI_DEPS_LOCAL)
fi

# Test harness dependencies.
pip install --no-index -f file://$PIP_CACHE cheetah

# Charmhelpers testing dependencies.
pip install --no-index -f file://$PIP_CACHE python-apt

# If any install failed, fail the whole script
if [ "$FAILURES" != "0" ] ; then
    echo "Number setup failures: $FAILURES"
    # exit only on failures so this script can still be sourced when
    # succeeding
    exit $FAILURES
fi
