# Ubuntu CI Engine
# Copyright 2014 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
import unittest


from ucitests import (
    features,
    fixtures,
)


from ci_utils import data_store
import tstrun
from tstrun import tests


class TestNovaCredentials(unittest.TestCase):

    def setUp(self):
        super(TestNovaCredentials, self).setUp()
        fixtures.set_uniq_cwd(self)

    def test_no_file(self):
        creds = tests.NovaCredentials('I-dont-exist')
        self.assertFalse(creds.available())

    def test_empty_file(self):
        path = 'empty'
        with open(path, 'w'):
            pass
        creds = tests.NovaCredentials(path)
        self.assertTrue(creds.available())


@features.requires(tests.nova_creds)
class TestDataStore(unittest.TestCase):
    """Integration tests against the data store.

    We care only about creating a store and putting files there.
    """

    def setUp(self):
        super(TestDataStore, self).setUp()
        fixtures.set_uniq_cwd(self)
        # We create a unique container to isolate ourselves
        self.store = data_store.DataStore(
            os.path.basename(self.uniq_dir),
            tstrun.get_auth_config(), public=True)
        self.addCleanup(self.store.delete, recursive=True)

    def test_store_created_empty(self):
        self.assertEqual([], self.store.list_files())

    def assertStoreUrl(self, expected_rel_path, actual_url):
        # FIXME: data_store use the container name twice in urls, as in:
        # 'test-runner.test/test-runner.test.cloudy', it should be
        # 'test-runner.test/cloudy' instead -- vila 2014-02-06
        expected_url = self.store.file_path(expected_rel_path)
        self.assertEqual(expected_url, actual_url)

    def test_put_file_stores_content(self):
        rel_path = 'foo'
        content = 'foo content'
        url = self.store.put_file(rel_path, content)
        self.assertStoreUrl(rel_path, url)
        # Get our content back
        self.assertEqual(content, self.store.get_file(rel_path))


if __name__ == '__main__':
    unittest.main()
