# Ubuntu CI Engine
# Copyright 2013, 2014 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import json

import mock

from django.test import TestCase
from ucitests import styles

import status


class TestStatus(TestCase):
    def test_index(self):
        '''Ensure the index is always retrievable.
        We can't really validate the content, but this is a good sanity check
        '''
        content = self.client.get('/status/').content
        self.assertIn('href="/status/" class="active">Engine health', content)

    @mock.patch('status.views.amqp_utils')
    @mock.patch('status.views._get')
    def test_queue_health_not_exist(self, get, amqp_utils):
        '''Ensure we return values when no consumers are found'''
        expected = [
            {'name': 'foo', 'consumers': None},
            {'name': 'bar', 'consumers': None},
        ]
        amqp_utils.MONITORED_QUEUES = [x['name'] for x in expected]
        get.return_value = '[]'
        vals = json.loads(self.client.get('/status/queue_health/').content)
        self.assertEqual(expected, vals)

    @mock.patch('status.views.amqp_utils')
    @mock.patch('status.views._get')
    def test_queue_health_partial(self, get, amqp_utils):
        '''Ensure we detect a single failed worker'''
        expected = [
            {'name': 'foo', 'consumers': 1},
            {'name': 'bar', 'consumers': None},
        ]
        amqp_utils.MONITORED_QUEUES = [x['name'] for x in expected]
        get.return_value = json.dumps([
            {'name': 'foo', 'consumers': 1},
        ])
        vals = json.loads(self.client.get('/status/queue_health/').content)
        self.assertEqual(expected, vals)


class TestPep8(styles.TestPep8):
    packages = [status]


class TestPyflakes(styles.TestPyflakes):
    packages = [status]
