import json
import urllib2

from django.http import HttpResponse
from django.shortcuts import render_to_response

from ci_utils import amqp_utils


def _get(url, realm=None, user=None, password=None):
    if realm:
        mgr = urllib2.HTTPPasswordMgrWithDefaultRealm()
        mgr.add_password(None, realm, user, password)
        handler = urllib2.HTTPBasicAuthHandler(mgr)

        resp = urllib2.build_opener(handler).open(url)
        return resp.read()

    return urllib2.urlopen(url)


def _queue_health():
    amqp_server = amqp_utils.get_config().AMQP_HOST
    queues = amqp_utils.MONITORED_QUEUES
    base = 'http://{}:55672'.format(amqp_server)

    try:
        # NOTE: juju leaves this guest/guest and doesn't seem to expose
        # anything in the relation to override it
        content = _get(base + '/api/queues', base, 'guest', 'guest')
        data = json.loads(content)
        data = [x for x in data if x['name'] in queues]
        # find missing queues
        found = [x['name'] for x in data]
        for x in queues:
            if x not in found:
                data.append({'name': x, 'consumers': None})
        return data
    except Exception as e:
        return {'error': str(e)}


def index(request):
    return render_to_response('status/index.html', {'active': 'status'})


def queue_health(request):
    health = _queue_health()
    return HttpResponse(json.dumps(health), content_type='application/json')
